@@ -1,3 +1,4 @@
+import json
 import secrets
 import sys
 
@@ -5,11 +6,11 @@ from ..transform import create_transform
 
 
 def transform_field_main(args):
-    transform = create_transform(args.transform)
+    transform = create_transform(args.transform, json.loads(args.params))
 
     if args.pepper is not None:
         pepper = args.pepper.encode("ascii")
     else:
         pepper = secrets.token_bytes(8)
 
-    print(transform.transform(args.field, pepper))
+    print(transform.transform(args.field, pepper) or '')
